@@ -5,7 +5,7 @@
 
 package Log::Report::Win32Locale;
 use vars '$VERSION';
-$VERSION = '0.12';
+$VERSION = '0.13';
 use base 'Exporter';
 
 our @EXPORT = qw/codepage_to_iso iso_to_codepage
@@ -38,7 +38,9 @@ sub iso_to_codepage($)
 }
 
 
-sub iso_locale(;$) { $codepage_to_iso(shift || ms_codepage_id || ms_locale) }
+sub iso_locale(;$)
+{   codepage_to_iso(shift || ms_codepage_id || ms_locale);
+}
 
 # the following functions are rewrites of Win32::Codepage version 1.00
 # Copyright 2005 Clotho Advanced Media, Inc.  Under perl license.
